<?php

namespace Litecms\Representative\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Representative\Models\Representative;

class RepresentativePolicy
{

    /**
     * Determine if the given user can view the representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function view(UserPolicy $user, Representative $representative)
    {
        if ($user->canDo('representative.representative.view') && $user->isAdmin()) {
            return true;
        }

        return $representative->user_id == user_id() && $representative->user_type == user_type();
    }

    /**
     * Determine if the given user can create a representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('representative.representative.create');
    }

    /**
     * Determine if the given user can update the given representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function update(UserPolicy $user, Representative $representative)
    {
        if ($user->canDo('representative.representative.edit') && $user->isAdmin()) {
            return true;
        }

        return $representative->user_id == user_id() && $representative->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Representative $representative)
    {
        return $representative->user_id == user_id() && $representative->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Representative $representative)
    {
        if ($user->canDo('representative.representative.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given representative.
     *
     * @param UserPolicy $user
     * @param Representative $representative
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Representative $representative)
    {
        if ($user->canDo('representative.representative.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
